@@ -9,13 +9,20 @@ config = context.config
 if config.config_file_name is not None:
     fileConfig(config.config_file_name)
 
+target_metadata = SQLModel.metadata
+target_metadata.naming_convention = {
+    "ix": "ix_%(column_0_label)s",
+    "uq": "uq_%(table_name)s_%(column_0_name)s",
+    "ck": "ck_%(table_name)s_`%(constraint_name)s`",
+    "fk": "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
+    "pk": "pk_%(table_name)s",
+}
+
 from lnschema_bionty import *  # noqa
 from lnschema_core import *  # noqa
 
 from lnschema_wetlab import *  # noqa
 
-target_metadata = SQLModel.metadata
-
 
 def run_migrations_offline() -> None:
     """Run migrations in 'offline' mode.
